diff --git a/hbase-examples/pom.xml b/hbase-examples/pom.xml
index ec9ba9f9976..468c01d3244 100644
--- a/hbase-examples/pom.xml
+++ b/hbase-examples/pom.xml
@@ -300,44 +300,5 @@ if we can combine these profiles somehow -->
-
- compile-protobuf
-
-
- compile-protobuf
-
-
-
-
-
- org.apache.hadoop
- hadoop-maven-plugins
-
-
- compile-protoc
- generate-sources
-
- protoc
-
-
-
- ${basedir}/src/main/protobuf
- ${basedir}/../hbase-protocol/src/main/protobuf
-
-
-
-
-
-
-
-
-
-
diff --git a/hbase-protocol/README.txt b/hbase-protocol/README.txt
index e651411bf64..4be401b3e83 100644
--- a/hbase-protocol/README.txt
+++ b/hbase-protocol/README.txt
@@ -1,15 +1,22 @@
-These are the protobuf definition files used by hbase. The produced java
-classes are generated into src/main/java/org/apache/hadoop/hbase/protobuf/generated
+These are the protobuf definition files used by hbase. ALL protobuf proto files
+must live in this module whether test or spark or coprocessor endpoint protos
+because we are being careful about what we expose of protobuf to downstreamers;
+we are shading our version of protobuf so we can freely change it as needed.
+
+The produced java classes are generated into
+src/main/java/org/apache/hadoop/hbase/protobuf/generated
and then checked in. The reasoning is that they change infrequently.
To regenerate the classes after making definition file changes, ensure first that
-the protobuf protoc tool is in your $PATH (You may need to download it and build
-it first; its part of the protobuf package obtainable from here:
-https://github.com/google/protobuf/releases/tag/v2.5.0).
+the protobuf protoc tool is in your $PATH. You may need to download it and build
+it first; its part of the protobuf package. For example, if using v2.5.0 of
+protobuf, it is obtainable from here:
-HBase uses hadoop-maven-plugins:protoc goal to invoke the protoc command. You can
-compile the protoc definitions by invoking maven with profile compile-protobuf or
-passing in compile-protobuf property.
+ https://github.com/google/protobuf/releases/tag/v2.5.0
+
+HBase uses hadoop-maven-plugins:protoc goal to invoke the protoc command. You can
+compile the protoc definitions by invoking maven with profile compile-protobuf or
+passing in compile-protobuf property.
mvn compile -Dcompile-protobuf
or
@@ -24,4 +31,3 @@ Other modules also support the maven profile.
After you've done the above, check it in and then check it in (or post a patch
on a JIRA with your definition file changes and the generated files).
-
diff --git a/hbase-protocol/pom.xml b/hbase-protocol/pom.xml
index 56ab13aef10..b7846ca6a12 100644
--- a/hbase-protocol/pom.xml
+++ b/hbase-protocol/pom.xml
@@ -203,6 +203,27 @@
VisibilityLabels.proto
WAL.proto
ZooKeeper.proto
+ SparkFilter.proto
+ ColumnAggregationNullResponseProtocol.proto
+ ColumnAggregationProtocol.proto
+ ColumnAggregationWithErrorsProtocol.proto
+ DummyRegionServerEndpoint.proto
+ IncrementCounterProcessor.proto
+ PingProtocol.proto
+ TestProcedure.proto
+ test.proto
+ test_rpc_service.proto
+ CellMessage.proto
+ CellSetMessage.proto
+ ColumnSchemaMessage.proto
+ NamespacePropertiesMessage.proto
+ NamespacesMessage.proto
+ ScannerMessage.proto
+ StorageClusterStatusMessage.proto
+ TableInfoMessage.proto
+ TableListMessage.proto
+ TableSchemaMessage.proto
+ VersionMessage.proto
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithErrorsProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithErrorsProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithErrorsProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithErrorsProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithNullResponseProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithNullResponseProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithNullResponseProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/ColumnAggregationWithNullResponseProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/DummyRegionServerEndpointProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/DummyRegionServerEndpointProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/DummyRegionServerEndpointProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/DummyRegionServerEndpointProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/IncrementCounterProcessorTestProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/IncrementCounterProcessorTestProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/IncrementCounterProcessorTestProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/IncrementCounterProcessorTestProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/PingProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/PingProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/PingProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/coprocessor/protobuf/generated/PingProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProcedureProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProcedureProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProcedureProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProcedureProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestProtos.java
diff --git a/hbase-server/src/test/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestRpcServiceProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestRpcServiceProtos.java
similarity index 100%
rename from hbase-server/src/test/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestRpcServiceProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/ipc/protobuf/generated/TestRpcServiceProtos.java
diff --git a/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/ClientProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/ClientProtos.java
index d7b8461c2d7..4e9e0b4dfa2 100644
--- a/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/ClientProtos.java
+++ b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/ClientProtos.java
@@ -21953,7 +21953,7 @@ public final class ClientProtos {
if (ref instanceof java.lang.String) {
return (java.lang.String) ref;
} else {
- com.google.protobuf.ByteString bs =
+ com.google.protobuf.ByteString bs =
(com.google.protobuf.ByteString) ref;
java.lang.String s = bs.toStringUtf8();
if (bs.isValidUtf8()) {
@@ -21969,7 +21969,7 @@ public final class ClientProtos {
getBulkTokenBytes() {
java.lang.Object ref = bulkToken_;
if (ref instanceof java.lang.String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
bulkToken_ = b;
@@ -22926,7 +22926,7 @@ public final class ClientProtos {
* optional .hbase.pb.DelegationToken fs_token = 4;
*/
private com.google.protobuf.SingleFieldBuilder<
- org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken.Builder, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationTokenOrBuilder>
+ org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken.Builder, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationTokenOrBuilder>
getFsTokenFieldBuilder() {
if (fsTokenBuilder_ == null) {
fsTokenBuilder_ = new com.google.protobuf.SingleFieldBuilder<
@@ -22968,7 +22968,7 @@ public final class ClientProtos {
getBulkTokenBytes() {
java.lang.Object ref = bulkToken_;
if (ref instanceof String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
bulkToken_ = b;
@@ -23397,7 +23397,7 @@ public final class ClientProtos {
public final boolean isInitialized() {
if (!hasLoaded()) {
-
+
return false;
}
return true;
@@ -23679,7 +23679,7 @@ public final class ClientProtos {
if (ref instanceof java.lang.String) {
return (java.lang.String) ref;
} else {
- com.google.protobuf.ByteString bs =
+ com.google.protobuf.ByteString bs =
(com.google.protobuf.ByteString) ref;
java.lang.String s = bs.toStringUtf8();
if (bs.isValidUtf8()) {
@@ -23695,7 +23695,7 @@ public final class ClientProtos {
getKindBytes() {
java.lang.Object ref = kind_;
if (ref instanceof java.lang.String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
kind_ = b;
@@ -23722,7 +23722,7 @@ public final class ClientProtos {
if (ref instanceof java.lang.String) {
return (java.lang.String) ref;
} else {
- com.google.protobuf.ByteString bs =
+ com.google.protobuf.ByteString bs =
(com.google.protobuf.ByteString) ref;
java.lang.String s = bs.toStringUtf8();
if (bs.isValidUtf8()) {
@@ -23738,7 +23738,7 @@ public final class ClientProtos {
getServiceBytes() {
java.lang.Object ref = service_;
if (ref instanceof java.lang.String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
service_ = b;
@@ -24196,7 +24196,7 @@ public final class ClientProtos {
getKindBytes() {
java.lang.Object ref = kind_;
if (ref instanceof String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
kind_ = b;
@@ -24270,7 +24270,7 @@ public final class ClientProtos {
getServiceBytes() {
java.lang.Object ref = service_;
if (ref instanceof String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
service_ = b;
@@ -24820,16 +24820,16 @@ public final class ClientProtos {
public final boolean isInitialized() {
if (!hasTableName()) {
-
+
return false;
}
if (!getTableName().isInitialized()) {
-
+
return false;
}
if (hasRegion()) {
if (!getRegion().isInitialized()) {
-
+
return false;
}
}
@@ -24959,7 +24959,7 @@ public final class ClientProtos {
* required .hbase.pb.TableName table_name = 1;
*/
private com.google.protobuf.SingleFieldBuilder<
- org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.TableName, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.TableName.Builder, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.TableNameOrBuilder>
+ org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.TableName, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.TableName.Builder, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.TableNameOrBuilder>
getTableNameFieldBuilder() {
if (tableNameBuilder_ == null) {
tableNameBuilder_ = new com.google.protobuf.SingleFieldBuilder<
@@ -25076,7 +25076,7 @@ public final class ClientProtos {
* optional .hbase.pb.RegionSpecifier region = 2;
*/
private com.google.protobuf.SingleFieldBuilder<
- org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier.Builder, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifierOrBuilder>
+ org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier.Builder, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifierOrBuilder>
getRegionFieldBuilder() {
if (regionBuilder_ == null) {
regionBuilder_ = new com.google.protobuf.SingleFieldBuilder<
@@ -25231,7 +25231,7 @@ public final class ClientProtos {
if (ref instanceof java.lang.String) {
return (java.lang.String) ref;
} else {
- com.google.protobuf.ByteString bs =
+ com.google.protobuf.ByteString bs =
(com.google.protobuf.ByteString) ref;
java.lang.String s = bs.toStringUtf8();
if (bs.isValidUtf8()) {
@@ -25247,7 +25247,7 @@ public final class ClientProtos {
getBulkTokenBytes() {
java.lang.Object ref = bulkToken_;
if (ref instanceof java.lang.String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
bulkToken_ = b;
@@ -25507,7 +25507,7 @@ public final class ClientProtos {
public final boolean isInitialized() {
if (!hasBulkToken()) {
-
+
return false;
}
return true;
@@ -25561,7 +25561,7 @@ public final class ClientProtos {
getBulkTokenBytes() {
java.lang.Object ref = bulkToken_;
if (ref instanceof String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
bulkToken_ = b;
@@ -25775,7 +25775,7 @@ public final class ClientProtos {
if (ref instanceof java.lang.String) {
return (java.lang.String) ref;
} else {
- com.google.protobuf.ByteString bs =
+ com.google.protobuf.ByteString bs =
(com.google.protobuf.ByteString) ref;
java.lang.String s = bs.toStringUtf8();
if (bs.isValidUtf8()) {
@@ -25791,7 +25791,7 @@ public final class ClientProtos {
getBulkTokenBytes() {
java.lang.Object ref = bulkToken_;
if (ref instanceof java.lang.String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
bulkToken_ = b;
@@ -26114,12 +26114,12 @@ public final class ClientProtos {
public final boolean isInitialized() {
if (!hasBulkToken()) {
-
+
return false;
}
if (hasRegion()) {
if (!getRegion().isInitialized()) {
-
+
return false;
}
}
@@ -26174,7 +26174,7 @@ public final class ClientProtos {
getBulkTokenBytes() {
java.lang.Object ref = bulkToken_;
if (ref instanceof String) {
- com.google.protobuf.ByteString b =
+ com.google.protobuf.ByteString b =
com.google.protobuf.ByteString.copyFromUtf8(
(java.lang.String) ref);
bulkToken_ = b;
@@ -26323,7 +26323,7 @@ public final class ClientProtos {
* optional .hbase.pb.RegionSpecifier region = 2;
*/
private com.google.protobuf.SingleFieldBuilder<
- org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier.Builder, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifierOrBuilder>
+ org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifier.Builder, org.apache.hadoop.hbase.protobuf.generated.HBaseProtos.RegionSpecifierOrBuilder>
getRegionFieldBuilder() {
if (regionBuilder_ == null) {
regionBuilder_ = new com.google.protobuf.SingleFieldBuilder<
diff --git a/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/SecureBulkLoadProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/SecureBulkLoadProtos.java
index 29c49de211c..528f6e64107 100644
--- a/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/SecureBulkLoadProtos.java
+++ b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/protobuf/generated/SecureBulkLoadProtos.java
@@ -1106,7 +1106,7 @@ public final class SecureBulkLoadProtos {
* required .hbase.pb.DelegationToken fs_token = 3;
*/
private com.google.protobuf.SingleFieldBuilder<
- org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken.Builder, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationTokenOrBuilder>
+ org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationToken.Builder, org.apache.hadoop.hbase.protobuf.generated.ClientProtos.DelegationTokenOrBuilder>
getFsTokenFieldBuilder() {
if (fsTokenBuilder_ == null) {
fsTokenBuilder_ = new com.google.protobuf.SingleFieldBuilder<
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellSetMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellSetMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellSetMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/CellSetMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ColumnSchemaMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ColumnSchemaMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ColumnSchemaMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ColumnSchemaMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacePropertiesMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacePropertiesMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacePropertiesMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacePropertiesMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacesMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacesMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacesMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/NamespacesMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ScannerMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ScannerMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ScannerMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/ScannerMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/StorageClusterStatusMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/StorageClusterStatusMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/StorageClusterStatusMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/StorageClusterStatusMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableInfoMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableInfoMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableInfoMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableInfoMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableListMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableListMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableListMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableListMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableSchemaMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableSchemaMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableSchemaMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/TableSchemaMessage.java
diff --git a/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/VersionMessage.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/VersionMessage.java
similarity index 100%
rename from hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/VersionMessage.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/rest/protobuf/generated/VersionMessage.java
diff --git a/hbase-spark/src/main/java/org/apache/hadoop/hbase/spark/protobuf/generated/FilterProtos.java b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/spark/protobuf/generated/SparkFilterProtos.java
similarity index 84%
rename from hbase-spark/src/main/java/org/apache/hadoop/hbase/spark/protobuf/generated/FilterProtos.java
rename to hbase-protocol/src/main/java/org/apache/hadoop/hbase/spark/protobuf/generated/SparkFilterProtos.java
index cbef1346d3d..ddd466e14b7 100644
--- a/hbase-spark/src/main/java/org/apache/hadoop/hbase/spark/protobuf/generated/FilterProtos.java
+++ b/hbase-protocol/src/main/java/org/apache/hadoop/hbase/spark/protobuf/generated/SparkFilterProtos.java
@@ -1,10 +1,10 @@
// Generated by the protocol buffer compiler. DO NOT EDIT!
-// source: Filter.proto
+// source: SparkFilter.proto
package org.apache.hadoop.hbase.spark.protobuf.generated;
-public final class FilterProtos {
- private FilterProtos() {}
+public final class SparkFilterProtos {
+ private SparkFilterProtos() {}
public static void registerAllExtensions(
com.google.protobuf.ExtensionRegistry registry) {
}
@@ -126,14 +126,14 @@ public final class FilterProtos {
}
public static final com.google.protobuf.Descriptors.Descriptor
getDescriptor() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_descriptor;
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_descriptor;
}
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable
internalGetFieldAccessorTable() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_fieldAccessorTable
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_fieldAccessorTable
.ensureFieldAccessorsInitialized(
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.class, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder.class);
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.class, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder.class);
}
public static com.google.protobuf.Parser PARSER =
@@ -303,10 +303,10 @@ public final class FilterProtos {
if (obj == this) {
return true;
}
- if (!(obj instanceof org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping)) {
+ if (!(obj instanceof org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping)) {
return super.equals(obj);
}
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping other = (org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping) obj;
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping other = (org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping) obj;
boolean result = true;
result = result && (hasColumnFamily() == other.hasColumnFamily());
@@ -354,53 +354,53 @@ public final class FilterProtos {
return hash;
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
com.google.protobuf.ByteString data)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
com.google.protobuf.ByteString data,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(byte[] data)
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(byte[] data)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
byte[] data,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(java.io.InputStream input)
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(java.io.InputStream input)
throws java.io.IOException {
return PARSER.parseFrom(input);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
java.io.InputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
return PARSER.parseFrom(input, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseDelimitedFrom(java.io.InputStream input)
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseDelimitedFrom(java.io.InputStream input)
throws java.io.IOException {
return PARSER.parseDelimitedFrom(input);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseDelimitedFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseDelimitedFrom(
java.io.InputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
return PARSER.parseDelimitedFrom(input, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
com.google.protobuf.CodedInputStream input)
throws java.io.IOException {
return PARSER.parseFrom(input);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parseFrom(
com.google.protobuf.CodedInputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
@@ -409,7 +409,7 @@ public final class FilterProtos {
public static Builder newBuilder() { return Builder.create(); }
public Builder newBuilderForType() { return newBuilder(); }
- public static Builder newBuilder(org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping prototype) {
+ public static Builder newBuilder(org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping prototype) {
return newBuilder().mergeFrom(prototype);
}
public Builder toBuilder() { return newBuilder(this); }
@@ -425,20 +425,20 @@ public final class FilterProtos {
*/
public static final class Builder extends
com.google.protobuf.GeneratedMessage.Builder
- implements org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder {
+ implements org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder {
public static final com.google.protobuf.Descriptors.Descriptor
getDescriptor() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_descriptor;
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_descriptor;
}
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable
internalGetFieldAccessorTable() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_fieldAccessorTable
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_fieldAccessorTable
.ensureFieldAccessorsInitialized(
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.class, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder.class);
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.class, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder.class);
}
- // Construct using org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.newBuilder()
+ // Construct using org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.newBuilder()
private Builder() {
maybeForceBuilderInitialization();
}
@@ -473,23 +473,23 @@ public final class FilterProtos {
public com.google.protobuf.Descriptors.Descriptor
getDescriptorForType() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_descriptor;
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownCellToColumnMapping_descriptor;
}
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping getDefaultInstanceForType() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance();
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping getDefaultInstanceForType() {
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance();
}
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping build() {
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping result = buildPartial();
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping build() {
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping result = buildPartial();
if (!result.isInitialized()) {
throw newUninitializedMessageException(result);
}
return result;
}
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping buildPartial() {
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping result = new org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping(this);
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping buildPartial() {
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping result = new org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping(this);
int from_bitField0_ = bitField0_;
int to_bitField0_ = 0;
if (((from_bitField0_ & 0x00000001) == 0x00000001)) {
@@ -510,16 +510,16 @@ public final class FilterProtos {
}
public Builder mergeFrom(com.google.protobuf.Message other) {
- if (other instanceof org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping) {
- return mergeFrom((org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping)other);
+ if (other instanceof org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping) {
+ return mergeFrom((org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping)other);
} else {
super.mergeFrom(other);
return this;
}
}
- public Builder mergeFrom(org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping other) {
- if (other == org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance()) return this;
+ public Builder mergeFrom(org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping other) {
+ if (other == org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance()) return this;
if (other.hasColumnFamily()) {
setColumnFamily(other.getColumnFamily());
}
@@ -555,11 +555,11 @@ public final class FilterProtos {
com.google.protobuf.CodedInputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping parsedMessage = null;
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping parsedMessage = null;
try {
parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
} catch (com.google.protobuf.InvalidProtocolBufferException e) {
- parsedMessage = (org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping) e.getUnfinishedMessage();
+ parsedMessage = (org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping) e.getUnfinishedMessage();
throw e;
} finally {
if (parsedMessage != null) {
@@ -763,12 +763,12 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- java.util.List
+ java.util.List
getCellToColumnMappingList();
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping getCellToColumnMapping(int index);
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping getCellToColumnMapping(int index);
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
@@ -776,12 +776,12 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- java.util.List extends org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
+ java.util.List extends org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
getCellToColumnMappingOrBuilderList();
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder getCellToColumnMappingOrBuilder(
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder getCellToColumnMappingOrBuilder(
int index);
// optional string encoderClassName = 4;
@@ -865,10 +865,10 @@ public final class FilterProtos {
}
case 26: {
if (!((mutable_bitField0_ & 0x00000004) == 0x00000004)) {
- cellToColumnMapping_ = new java.util.ArrayList();
+ cellToColumnMapping_ = new java.util.ArrayList();
mutable_bitField0_ |= 0x00000004;
}
- cellToColumnMapping_.add(input.readMessage(org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.PARSER, extensionRegistry));
+ cellToColumnMapping_.add(input.readMessage(org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.PARSER, extensionRegistry));
break;
}
case 34: {
@@ -896,14 +896,14 @@ public final class FilterProtos {
}
public static final com.google.protobuf.Descriptors.Descriptor
getDescriptor() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_descriptor;
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_descriptor;
}
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable
internalGetFieldAccessorTable() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_fieldAccessorTable
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_fieldAccessorTable
.ensureFieldAccessorsInitialized(
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter.class, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter.Builder.class);
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter.class, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter.Builder.class);
}
public static com.google.protobuf.Parser PARSER =
@@ -990,17 +990,17 @@ public final class FilterProtos {
// repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
public static final int CELL_TO_COLUMN_MAPPING_FIELD_NUMBER = 3;
- private java.util.List cellToColumnMapping_;
+ private java.util.List cellToColumnMapping_;
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public java.util.List getCellToColumnMappingList() {
+ public java.util.List getCellToColumnMappingList() {
return cellToColumnMapping_;
}
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public java.util.List extends org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
+ public java.util.List extends org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
getCellToColumnMappingOrBuilderList() {
return cellToColumnMapping_;
}
@@ -1013,13 +1013,13 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping getCellToColumnMapping(int index) {
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping getCellToColumnMapping(int index) {
return cellToColumnMapping_.get(index);
}
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder getCellToColumnMappingOrBuilder(
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder getCellToColumnMappingOrBuilder(
int index) {
return cellToColumnMapping_.get(index);
}
@@ -1154,10 +1154,10 @@ public final class FilterProtos {
if (obj == this) {
return true;
}
- if (!(obj instanceof org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter)) {
+ if (!(obj instanceof org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter)) {
return super.equals(obj);
}
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter other = (org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter) obj;
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter other = (org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter) obj;
boolean result = true;
result = result && (hasDynamicLogicExpression() == other.hasDynamicLogicExpression());
@@ -1208,53 +1208,53 @@ public final class FilterProtos {
return hash;
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(
com.google.protobuf.ByteString data)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(
com.google.protobuf.ByteString data,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(byte[] data)
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(byte[] data)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(
byte[] data,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws com.google.protobuf.InvalidProtocolBufferException {
return PARSER.parseFrom(data, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(java.io.InputStream input)
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(java.io.InputStream input)
throws java.io.IOException {
return PARSER.parseFrom(input);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(
java.io.InputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
return PARSER.parseFrom(input, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseDelimitedFrom(java.io.InputStream input)
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseDelimitedFrom(java.io.InputStream input)
throws java.io.IOException {
return PARSER.parseDelimitedFrom(input);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseDelimitedFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseDelimitedFrom(
java.io.InputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
return PARSER.parseDelimitedFrom(input, extensionRegistry);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(
com.google.protobuf.CodedInputStream input)
throws java.io.IOException {
return PARSER.parseFrom(input);
}
- public static org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parseFrom(
+ public static org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parseFrom(
com.google.protobuf.CodedInputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
@@ -1263,7 +1263,7 @@ public final class FilterProtos {
public static Builder newBuilder() { return Builder.create(); }
public Builder newBuilderForType() { return newBuilder(); }
- public static Builder newBuilder(org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter prototype) {
+ public static Builder newBuilder(org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter prototype) {
return newBuilder().mergeFrom(prototype);
}
public Builder toBuilder() { return newBuilder(this); }
@@ -1279,20 +1279,20 @@ public final class FilterProtos {
*/
public static final class Builder extends
com.google.protobuf.GeneratedMessage.Builder
- implements org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilterOrBuilder {
+ implements org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilterOrBuilder {
public static final com.google.protobuf.Descriptors.Descriptor
getDescriptor() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_descriptor;
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_descriptor;
}
protected com.google.protobuf.GeneratedMessage.FieldAccessorTable
internalGetFieldAccessorTable() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_fieldAccessorTable
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_fieldAccessorTable
.ensureFieldAccessorsInitialized(
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter.class, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter.Builder.class);
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter.class, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter.Builder.class);
}
- // Construct using org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter.newBuilder()
+ // Construct using org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter.newBuilder()
private Builder() {
maybeForceBuilderInitialization();
}
@@ -1334,23 +1334,23 @@ public final class FilterProtos {
public com.google.protobuf.Descriptors.Descriptor
getDescriptorForType() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_descriptor;
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.internal_static_hbase_pb_SQLPredicatePushDownFilter_descriptor;
}
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter getDefaultInstanceForType() {
- return org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter.getDefaultInstance();
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter getDefaultInstanceForType() {
+ return org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter.getDefaultInstance();
}
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter build() {
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter result = buildPartial();
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter build() {
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter result = buildPartial();
if (!result.isInitialized()) {
throw newUninitializedMessageException(result);
}
return result;
}
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter buildPartial() {
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter result = new org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter(this);
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter buildPartial() {
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter result = new org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter(this);
int from_bitField0_ = bitField0_;
int to_bitField0_ = 0;
if (((from_bitField0_ & 0x00000001) == 0x00000001)) {
@@ -1381,16 +1381,16 @@ public final class FilterProtos {
}
public Builder mergeFrom(com.google.protobuf.Message other) {
- if (other instanceof org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter) {
- return mergeFrom((org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter)other);
+ if (other instanceof org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter) {
+ return mergeFrom((org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter)other);
} else {
super.mergeFrom(other);
return this;
}
}
- public Builder mergeFrom(org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter other) {
- if (other == org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter.getDefaultInstance()) return this;
+ public Builder mergeFrom(org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter other) {
+ if (other == org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter.getDefaultInstance()) return this;
if (other.hasDynamicLogicExpression()) {
bitField0_ |= 0x00000001;
dynamicLogicExpression_ = other.dynamicLogicExpression_;
@@ -1459,11 +1459,11 @@ public final class FilterProtos {
com.google.protobuf.CodedInputStream input,
com.google.protobuf.ExtensionRegistryLite extensionRegistry)
throws java.io.IOException {
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter parsedMessage = null;
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter parsedMessage = null;
try {
parsedMessage = PARSER.parsePartialFrom(input, extensionRegistry);
} catch (com.google.protobuf.InvalidProtocolBufferException e) {
- parsedMessage = (org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownFilter) e.getUnfinishedMessage();
+ parsedMessage = (org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownFilter) e.getUnfinishedMessage();
throw e;
} finally {
if (parsedMessage != null) {
@@ -1621,22 +1621,22 @@ public final class FilterProtos {
}
// repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
- private java.util.List cellToColumnMapping_ =
+ private java.util.List cellToColumnMapping_ =
java.util.Collections.emptyList();
private void ensureCellToColumnMappingIsMutable() {
if (!((bitField0_ & 0x00000004) == 0x00000004)) {
- cellToColumnMapping_ = new java.util.ArrayList(cellToColumnMapping_);
+ cellToColumnMapping_ = new java.util.ArrayList(cellToColumnMapping_);
bitField0_ |= 0x00000004;
}
}
private com.google.protobuf.RepeatedFieldBuilder<
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder> cellToColumnMappingBuilder_;
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder> cellToColumnMappingBuilder_;
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public java.util.List getCellToColumnMappingList() {
+ public java.util.List getCellToColumnMappingList() {
if (cellToColumnMappingBuilder_ == null) {
return java.util.Collections.unmodifiableList(cellToColumnMapping_);
} else {
@@ -1656,7 +1656,7 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping getCellToColumnMapping(int index) {
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping getCellToColumnMapping(int index) {
if (cellToColumnMappingBuilder_ == null) {
return cellToColumnMapping_.get(index);
} else {
@@ -1667,7 +1667,7 @@ public final class FilterProtos {
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
public Builder setCellToColumnMapping(
- int index, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping value) {
+ int index, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping value) {
if (cellToColumnMappingBuilder_ == null) {
if (value == null) {
throw new NullPointerException();
@@ -1684,7 +1684,7 @@ public final class FilterProtos {
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
public Builder setCellToColumnMapping(
- int index, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder builderForValue) {
+ int index, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder builderForValue) {
if (cellToColumnMappingBuilder_ == null) {
ensureCellToColumnMappingIsMutable();
cellToColumnMapping_.set(index, builderForValue.build());
@@ -1697,7 +1697,7 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public Builder addCellToColumnMapping(org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping value) {
+ public Builder addCellToColumnMapping(org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping value) {
if (cellToColumnMappingBuilder_ == null) {
if (value == null) {
throw new NullPointerException();
@@ -1714,7 +1714,7 @@ public final class FilterProtos {
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
public Builder addCellToColumnMapping(
- int index, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping value) {
+ int index, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping value) {
if (cellToColumnMappingBuilder_ == null) {
if (value == null) {
throw new NullPointerException();
@@ -1731,7 +1731,7 @@ public final class FilterProtos {
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
public Builder addCellToColumnMapping(
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder builderForValue) {
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder builderForValue) {
if (cellToColumnMappingBuilder_ == null) {
ensureCellToColumnMappingIsMutable();
cellToColumnMapping_.add(builderForValue.build());
@@ -1745,7 +1745,7 @@ public final class FilterProtos {
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
public Builder addCellToColumnMapping(
- int index, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder builderForValue) {
+ int index, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder builderForValue) {
if (cellToColumnMappingBuilder_ == null) {
ensureCellToColumnMappingIsMutable();
cellToColumnMapping_.add(index, builderForValue.build());
@@ -1759,7 +1759,7 @@ public final class FilterProtos {
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
public Builder addAllCellToColumnMapping(
- java.lang.Iterable extends org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping> values) {
+ java.lang.Iterable extends org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping> values) {
if (cellToColumnMappingBuilder_ == null) {
ensureCellToColumnMappingIsMutable();
super.addAll(values, cellToColumnMapping_);
@@ -1798,14 +1798,14 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder getCellToColumnMappingBuilder(
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder getCellToColumnMappingBuilder(
int index) {
return getCellToColumnMappingFieldBuilder().getBuilder(index);
}
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder getCellToColumnMappingOrBuilder(
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder getCellToColumnMappingOrBuilder(
int index) {
if (cellToColumnMappingBuilder_ == null) {
return cellToColumnMapping_.get(index); } else {
@@ -1815,7 +1815,7 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public java.util.List extends org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
+ public java.util.List extends org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
getCellToColumnMappingOrBuilderList() {
if (cellToColumnMappingBuilder_ != null) {
return cellToColumnMappingBuilder_.getMessageOrBuilderList();
@@ -1826,31 +1826,31 @@ public final class FilterProtos {
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder addCellToColumnMappingBuilder() {
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder addCellToColumnMappingBuilder() {
return getCellToColumnMappingFieldBuilder().addBuilder(
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance());
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance());
}
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder addCellToColumnMappingBuilder(
+ public org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder addCellToColumnMappingBuilder(
int index) {
return getCellToColumnMappingFieldBuilder().addBuilder(
- index, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance());
+ index, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.getDefaultInstance());
}
/**
* repeated .hbase.pb.SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
*/
- public java.util.List
+ public java.util.List
getCellToColumnMappingBuilderList() {
return getCellToColumnMappingFieldBuilder().getBuilderList();
}
private com.google.protobuf.RepeatedFieldBuilder<
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>
getCellToColumnMappingFieldBuilder() {
if (cellToColumnMappingBuilder_ == null) {
cellToColumnMappingBuilder_ = new com.google.protobuf.RepeatedFieldBuilder<
- org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder, org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>(
+ org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder, org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos.SQLPredicatePushDownCellToColumnMappingOrBuilder>(
cellToColumnMapping_,
((bitField0_ & 0x00000004) == 0x00000004),
getParentForChildren(),
@@ -1964,17 +1964,17 @@ public final class FilterProtos {
descriptor;
static {
java.lang.String[] descriptorData = {
- "\n\014Filter.proto\022\010hbase.pb\"h\n\'SQLPredicate" +
- "PushDownCellToColumnMapping\022\025\n\rcolumn_fa" +
- "mily\030\001 \002(\014\022\021\n\tqualifier\030\002 \002(\014\022\023\n\013column_" +
- "name\030\003 \002(\t\"\313\001\n\032SQLPredicatePushDownFilte" +
- "r\022 \n\030dynamic_logic_expression\030\001 \002(\t\022\036\n\026v" +
- "alue_from_query_array\030\002 \003(\014\022Q\n\026cell_to_c" +
- "olumn_mapping\030\003 \003(\01321.hbase.pb.SQLPredic" +
- "atePushDownCellToColumnMapping\022\030\n\020encode" +
- "rClassName\030\004 \001(\tBH\n0org.apache.hadoop.hb" +
- "ase.spark.protobuf.generatedB\014FilterProt",
- "osH\001\210\001\001\240\001\001"
+ "\n\021SparkFilter.proto\022\010hbase.pb\"h\n\'SQLPred" +
+ "icatePushDownCellToColumnMapping\022\025\n\rcolu" +
+ "mn_family\030\001 \002(\014\022\021\n\tqualifier\030\002 \002(\014\022\023\n\013co" +
+ "lumn_name\030\003 \002(\t\"\313\001\n\032SQLPredicatePushDown" +
+ "Filter\022 \n\030dynamic_logic_expression\030\001 \002(\t" +
+ "\022\036\n\026value_from_query_array\030\002 \003(\014\022Q\n\026cell" +
+ "_to_column_mapping\030\003 \003(\01321.hbase.pb.SQLP" +
+ "redicatePushDownCellToColumnMapping\022\030\n\020e" +
+ "ncoderClassName\030\004 \001(\tBM\n0org.apache.hado" +
+ "op.hbase.spark.protobuf.generatedB\021Spark",
+ "FilterProtosH\001\210\001\001\240\001\001"
};
com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner assigner =
new com.google.protobuf.Descriptors.FileDescriptor.InternalDescriptorAssigner() {
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/StorageClusterStatusMessage.proto b/hbase-protocol/src/main/protobuf/StorageClusterStatusMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/StorageClusterStatusMessage.proto
rename to hbase-protocol/src/main/protobuf/StorageClusterStatusMessage.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/TableInfoMessage.proto b/hbase-protocol/src/main/protobuf/TableInfoMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/TableInfoMessage.proto
rename to hbase-protocol/src/main/protobuf/TableInfoMessage.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/TableListMessage.proto b/hbase-protocol/src/main/protobuf/TableListMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/TableListMessage.proto
rename to hbase-protocol/src/main/protobuf/TableListMessage.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/TableSchemaMessage.proto b/hbase-protocol/src/main/protobuf/TableSchemaMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/TableSchemaMessage.proto
rename to hbase-protocol/src/main/protobuf/TableSchemaMessage.proto
diff --git a/hbase-server/src/test/protobuf/TestProcedure.proto b/hbase-protocol/src/main/protobuf/TestProcedure.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/TestProcedure.proto
rename to hbase-protocol/src/main/protobuf/TestProcedure.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/VersionMessage.proto b/hbase-protocol/src/main/protobuf/VersionMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/VersionMessage.proto
rename to hbase-protocol/src/main/protobuf/VersionMessage.proto
diff --git a/hbase-server/src/test/protobuf/test.proto b/hbase-protocol/src/main/protobuf/test.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/test.proto
rename to hbase-protocol/src/main/protobuf/test.proto
diff --git a/hbase-server/src/test/protobuf/test_rpc_service.proto b/hbase-protocol/src/main/protobuf/test_rpc_service.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/test_rpc_service.proto
rename to hbase-protocol/src/main/protobuf/test_rpc_service.proto
diff --git a/hbase-rest/pom.xml b/hbase-rest/pom.xml
index a66be01eebc..2e1b245e9e4 100644
--- a/hbase-rest/pom.xml
+++ b/hbase-rest/pom.xml
@@ -186,6 +186,11 @@
hbase-common
jar
+
+ org.apache.hbase
+ hbase-protocol
+ jar
+
org.apache.hbase
hbase-annotations
@@ -334,56 +339,6 @@
true
-
- compile-protobuf
-
-
- compile-protobuf
-
-
-
-
-
- org.apache.hadoop
- hadoop-maven-plugins
-
-
- compile-protoc
- generate-sources
-
- protoc
-
-
-
- ${basedir}/src/main/resources/org/apache/hadoop/hbase/rest/protobuf
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/hbase-spark/src/main/java/org/apache/hadoop/hbase/spark/SparkSQLPushDownFilter.java b/hbase-spark/src/main/java/org/apache/hadoop/hbase/spark/SparkSQLPushDownFilter.java
index 071c1ca6f1e..fa66d69c6f3 100644
--- a/hbase-spark/src/main/java/org/apache/hadoop/hbase/spark/SparkSQLPushDownFilter.java
+++ b/hbase-spark/src/main/java/org/apache/hadoop/hbase/spark/SparkSQLPushDownFilter.java
@@ -26,7 +26,7 @@ import org.apache.hadoop.hbase.exceptions.DeserializationException;
import org.apache.hadoop.hbase.filter.FilterBase;
import org.apache.hadoop.hbase.spark.datasources.BytesEncoder;
import org.apache.hadoop.hbase.spark.datasources.JavaBytesEncoder;
-import org.apache.hadoop.hbase.spark.protobuf.generated.FilterProtos;
+import org.apache.hadoop.hbase.spark.protobuf.generated.SparkFilterProtos;
import org.apache.hadoop.hbase.util.ByteStringer;
import org.apache.hadoop.hbase.util.Bytes;
import org.apache.spark.sql.datasources.hbase.Field;
@@ -183,9 +183,9 @@ public class SparkSQLPushDownFilter extends FilterBase{
public static SparkSQLPushDownFilter parseFrom(final byte[] pbBytes)
throws DeserializationException {
- FilterProtos.SQLPredicatePushDownFilter proto;
+ SparkFilterProtos.SQLPredicatePushDownFilter proto;
try {
- proto = FilterProtos.SQLPredicatePushDownFilter.parseFrom(pbBytes);
+ proto = SparkFilterProtos.SQLPredicatePushDownFilter.parseFrom(pbBytes);
} catch (InvalidProtocolBufferException e) {
throw new DeserializationException(e);
}
@@ -208,7 +208,7 @@ public class SparkSQLPushDownFilter extends FilterBase{
HashMap>
currentCellToColumnIndexMap = new HashMap<>();
- for (FilterProtos.SQLPredicatePushDownCellToColumnMapping
+ for (SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping
sqlPredicatePushDownCellToColumnMapping :
proto.getCellToColumnMappingList()) {
@@ -242,11 +242,11 @@ public class SparkSQLPushDownFilter extends FilterBase{
*/
public byte[] toByteArray() {
- FilterProtos.SQLPredicatePushDownFilter.Builder builder =
- FilterProtos.SQLPredicatePushDownFilter.newBuilder();
+ SparkFilterProtos.SQLPredicatePushDownFilter.Builder builder =
+ SparkFilterProtos.SQLPredicatePushDownFilter.newBuilder();
- FilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder columnMappingBuilder =
- FilterProtos.SQLPredicatePushDownCellToColumnMapping.newBuilder();
+ SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.Builder columnMappingBuilder =
+ SparkFilterProtos.SQLPredicatePushDownCellToColumnMapping.newBuilder();
builder.setDynamicLogicExpression(dynamicLogicExpression.toExpressionString());
for (byte[] valueFromQuery: valueFromQueryArray) {
diff --git a/src/main/asciidoc/_chapters/developer.adoc b/src/main/asciidoc/_chapters/developer.adoc
index 74ce3dfa4e4..56aa5577f44 100644
--- a/src/main/asciidoc/_chapters/developer.adoc
+++ b/src/main/asciidoc/_chapters/developer.adoc
@@ -351,6 +351,10 @@ mvn -Dhadoop.profile=22 ...
You may need to change the protobuf definitions that reside in the _hbase-protocol_ module or other modules.
+Previous to hbase-2.0.0, protobuf definition files were sprinkled across all hbase modules but now all
+to do with protobuf must reside in the hbase-protocol module; we are trying to contain our protobuf
+use so we can freely change versions without upsetting any downstream project use of protobuf.
+
The protobuf files are located in _hbase-protocol/src/main/protobuf_.
For the change to be effective, you will need to regenerate the classes.
You can use maven profile `compile-protobuf` to do this.
diff --git a/hbase-examples/src/main/protobuf/BulkDelete.proto b/hbase-protocol/src/main/protobuf/BulkDelete.proto
similarity index 100%
rename from hbase-examples/src/main/protobuf/BulkDelete.proto
rename to hbase-protocol/src/main/protobuf/BulkDelete.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/CellMessage.proto b/hbase-protocol/src/main/protobuf/CellMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/CellMessage.proto
rename to hbase-protocol/src/main/protobuf/CellMessage.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/CellSetMessage.proto b/hbase-protocol/src/main/protobuf/CellSetMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/CellSetMessage.proto
rename to hbase-protocol/src/main/protobuf/CellSetMessage.proto
diff --git a/hbase-server/src/test/protobuf/ColumnAggregationNullResponseProtocol.proto b/hbase-protocol/src/main/protobuf/ColumnAggregationNullResponseProtocol.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/ColumnAggregationNullResponseProtocol.proto
rename to hbase-protocol/src/main/protobuf/ColumnAggregationNullResponseProtocol.proto
diff --git a/hbase-server/src/test/protobuf/ColumnAggregationProtocol.proto b/hbase-protocol/src/main/protobuf/ColumnAggregationProtocol.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/ColumnAggregationProtocol.proto
rename to hbase-protocol/src/main/protobuf/ColumnAggregationProtocol.proto
diff --git a/hbase-server/src/test/protobuf/ColumnAggregationWithErrorsProtocol.proto b/hbase-protocol/src/main/protobuf/ColumnAggregationWithErrorsProtocol.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/ColumnAggregationWithErrorsProtocol.proto
rename to hbase-protocol/src/main/protobuf/ColumnAggregationWithErrorsProtocol.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/ColumnSchemaMessage.proto b/hbase-protocol/src/main/protobuf/ColumnSchemaMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/ColumnSchemaMessage.proto
rename to hbase-protocol/src/main/protobuf/ColumnSchemaMessage.proto
diff --git a/hbase-server/src/test/protobuf/DummyRegionServerEndpoint.proto b/hbase-protocol/src/main/protobuf/DummyRegionServerEndpoint.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/DummyRegionServerEndpoint.proto
rename to hbase-protocol/src/main/protobuf/DummyRegionServerEndpoint.proto
diff --git a/hbase-examples/src/main/protobuf/Examples.proto b/hbase-protocol/src/main/protobuf/Examples.proto
similarity index 100%
rename from hbase-examples/src/main/protobuf/Examples.proto
rename to hbase-protocol/src/main/protobuf/Examples.proto
diff --git a/hbase-server/src/test/protobuf/IncrementCounterProcessor.proto b/hbase-protocol/src/main/protobuf/IncrementCounterProcessor.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/IncrementCounterProcessor.proto
rename to hbase-protocol/src/main/protobuf/IncrementCounterProcessor.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/NamespacePropertiesMessage.proto b/hbase-protocol/src/main/protobuf/NamespacePropertiesMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/NamespacePropertiesMessage.proto
rename to hbase-protocol/src/main/protobuf/NamespacePropertiesMessage.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/NamespacesMessage.proto b/hbase-protocol/src/main/protobuf/NamespacesMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/NamespacesMessage.proto
rename to hbase-protocol/src/main/protobuf/NamespacesMessage.proto
diff --git a/hbase-server/src/test/protobuf/PingProtocol.proto b/hbase-protocol/src/main/protobuf/PingProtocol.proto
similarity index 100%
rename from hbase-server/src/test/protobuf/PingProtocol.proto
rename to hbase-protocol/src/main/protobuf/PingProtocol.proto
diff --git a/hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/ScannerMessage.proto b/hbase-protocol/src/main/protobuf/ScannerMessage.proto
similarity index 100%
rename from hbase-rest/src/main/resources/org/apache/hadoop/hbase/rest/protobuf/ScannerMessage.proto
rename to hbase-protocol/src/main/protobuf/ScannerMessage.proto
diff --git a/hbase-spark/src/main/protobuf/Filter.proto b/hbase-protocol/src/main/protobuf/SparkFilter.proto
similarity index 89%
rename from hbase-spark/src/main/protobuf/Filter.proto
rename to hbase-protocol/src/main/protobuf/SparkFilter.proto
index d17b48cf696..e16c5517882 100644
--- a/hbase-spark/src/main/protobuf/Filter.proto
+++ b/hbase-protocol/src/main/protobuf/SparkFilter.proto
@@ -16,11 +16,12 @@
* limitations under the License.
*/
// This file contains protocol buffers that are used for filters
package hbase.pb;
option java_package = "org.apache.hadoop.hbase.spark.protobuf.generated";
-option java_outer_classname = "FilterProtos";
+option java_outer_classname = "SparkFilterProtos";
option java_generic_services = true;
option java_generate_equals_and_hash = true;
option optimize_for = SPEED;
@@ -36,4 +37,4 @@ message SQLPredicatePushDownFilter {
repeated bytes value_from_query_array = 2;
repeated SQLPredicatePushDownCellToColumnMapping cell_to_column_mapping = 3;
optional string encoderClassName = 4;
-}
\ No newline at end of file
+}
@@ -16,11 +16,12 @@
* limitations under the License.
*/
-// This file contains protocol buffers that are used for filters
+// This file contains protocol buffers that are used for Spark filters
+// over in the hbase-spark module
package hbase.pb;
option java_package = "org.apache.hadoop.hbase.spark.protobuf.generated";